pub fn verify_consistency(
old_root: &str,
old_size: u64,
new_head: &TreeHead,
proof: &ConsistencyProof,
) -> Result<()>Expand description
RFC 6962 2.1.2 consistency proof verification. Given the old root, the old size, the new (claimed) head, and the consistency proof from the server, verify that the new head is a valid append-only continuation of the old tree.